aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSeshu Kumar M <seshu.kumar.m@huawei.com>2017-09-22 09:18:02 +0000
committerGerrit Code Review <gerrit@onap.org>2017-09-22 09:18:02 +0000
commita04256b0c3f1cd61f8c3c0c4870546f642db3c70 (patch)
tree542276cb3d832d35686e6e73d6bab5afcd7f3758
parente07baf7bb429829483db01706c645adc3673ba92 (diff)
parent5bf86e26723ccae445073f8c88168d12fbb0c809 (diff)
Merge "Correct the class name"
-rw-r--r--bpmn/MSOInfrastructureBPMN/src/main/groovy/org/openecomp/mso/bpmn/infrastructure/scripts/DoCreateVFCNetworkServiceInstance.groovy6
1 files changed, 3 insertions, 3 deletions
diff --git a/bpmn/MSOInfrastructureBPMN/src/main/groovy/org/openecomp/mso/bpmn/infrastructure/scripts/DoCreateVFCNetworkServiceInstance.groovy b/bpmn/MSOInfrastructureBPMN/src/main/groovy/org/openecomp/mso/bpmn/infrastructure/scripts/DoCreateVFCNetworkServiceInstance.groovy
index ad0f6bc9b3..14fd419624 100644
--- a/bpmn/MSOInfrastructureBPMN/src/main/groovy/org/openecomp/mso/bpmn/infrastructure/scripts/DoCreateVFCNetworkServiceInstance.groovy
+++ b/bpmn/MSOInfrastructureBPMN/src/main/groovy/org/openecomp/mso/bpmn/infrastructure/scripts/DoCreateVFCNetworkServiceInstance.groovy
@@ -41,10 +41,10 @@ import org.openecomp.mso.rest.RESTConfig
import org.openecomp.mso.rest.APIResponse;
/**
* This groovy class supports the <class>CreateGenericE2EServiceInstance.bpmn</class> process.
* flow for E2E ServiceInstance Create
*/
-public class CreateGenericE2EServiceInstance extends AbstractServiceTaskProcessor {
+public class DoCreateVFCNetworkServiceInstance extends AbstractServiceTaskProcessor {
String createUrl = "/vfc/vfcadapters/v1/ns"
@@ -41,10 +41,10 @@ import org.openecomp.mso.rest.RESTConfig
import org.openecomp.mso.rest.APIResponse;
/**
- * This groovy class supports the <class>CreateGenericE2EServiceInstance.bpmn</class> process.
- * flow for E2E ServiceInstance Create
+ * This groovy class supports the <class>DoCreateVFCNetworkServiceInstance.bpmn</class> process.
+ * flow for VFC Network Service Create
*/